@@ -10,7 +10,7 @@
 # This file is provided by the wpasupplicant package.
 
 #####################################################################
-# Copyright (C) 2006 - 2008 Debian/Ubuntu wpasupplicant Maintainers 
+# Copyright (C) 2006 - 2009 Debian/Ubuntu wpasupplicant Maintainers 
 # <pkg-wpa-devel@lists.alioth.debian.org>
 #
 # This program is free software; you can redistribute it and/or
@@ -23,8 +23,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# On Debian GNU/Linux systems, the text of the GPL license can be
-# found in /usr/share/common-licenses/GPL.
+# On Debian GNU/Linux systems, the text of the GPL license,
+# version 2, can be found in /usr/share/common-licenses/GPL-2.
 
 #####################################################################
 ## global variables
@@ -32,7 +32,6 @@
 WPA_SUP_BIN="/sbin/wpa_supplicant"
 WPA_SUP_PNAME="wpa_supplicant"
 WPA_SUP_PIDFILE="/var/run/wpa_supplicant.${WPA_IFACE}.pid"
-WPA_SUP_LOGFILE="/var/log/wpa_supplicant.${WPA_IFACE}.log"
 
 # wpa_cli variables
 WPA_CLI_BIN="/sbin/wpa_cli"
@@ -176,13 +175,14 @@ test_wpa_cli () {
 # Start wpa_supplicant via start-stop-dameon with all required
 # options. Will start if environment variable WPA_SUP_CONF is present
 #
-# Required options:
+# Default options:
 # -B	dameonize/background process
 # -D	driver backend ('wext' if none given)
 # -P	process ID file
 # -C	path to ctrl_interface socket directory
+# -s    log to syslog
 #
-# Optional options:
+# Conditional options:
 # -c	configuration file
 # -W	wait for wpa_cli to attach to ctrl_interface socket
 # -b	bridge interface name
@@ -192,17 +192,16 @@ init_wpa_supplicant () {
 	[ -n "$WPA_SUP_CONF" ] || return 0
 
 	local WPA_SUP_OPTIONS
+	WPA_SUP_OPTIONS="-s -B -P $WPA_SUP_PIDFILE -i $WPA_IFACE"
 
 	if [ -n "$WPA_ACTION_SCRIPT" ]; then
 		if [ -x "$WPA_ACTION_SCRIPT" ]; then
-			WPA_SUP_OPTIONS="-W -B -P $WPA_SUP_PIDFILE -i $WPA_IFACE"
+			WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -W"
 			wpa_msg verbose "wait for wpa_cli to attach"
 		else
 			wpa_msg stderr "action script \"$WPA_ACTION_SCRIPT\" not executable"
 			return 1
 		fi
-	else
-		WPA_SUP_OPTIONS="-B -P $WPA_SUP_PIDFILE -i $WPA_IFACE"
 	fi
 
 	if [ -n "$IF_WPA_BRIDGE" ]; then
@@ -249,23 +248,15 @@ init_wpa_supplicant () {
 				;;
 		esac
 		wpa_msg verbose "using debug level: $IF_WPA_DEBUG_LEVEL"
-	else
-		# log warnings only by default
-		WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -q"
 	fi
 
 	if [ -n "$IF_WPA_LOGFILE" ]; then
 		# custom log file
+		WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -f $IF_WPA_LOGFILE"
 		WPA_SUP_LOGFILE="$IF_WPA_LOGFILE"
 		wpa_msg verbose "logging to $IF_WPA_LOGFILE"
 	fi
 
-	if [ -d "${WPA_SUP_LOGFILE%/*}" ]; then
-		WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -f $WPA_SUP_LOGFILE"
-	else
-		wpa_msg stderr "unable to log output to $WPA_SUP_LOGFILE"
-	fi
-
 	wpa_msg verbose "$WPA_SUP_BIN $WPA_SUP_OPTIONS $WPA_SUP_CONF"
 		
 	start-stop-daemon --start --oknodo $DAEMON_VERBOSITY \
@@ -861,20 +852,26 @@ conf_wpa_supplicant () {
 # Log actions to file
 #
 wpa_log_init () {
-	exec >> "$WPA_CLI_LOGFILE" 2>&1
+	if touch "$WPA_CLI_LOGFILE" 2>/dev/null; then
+		exec >> "$WPA_CLI_LOGFILE" 2>&1
+	fi
 }
 
 # log timestamp and wpa_action arguments
 wpa_log_action () {
-	local DATE
+	[ -w "$WPA_CLI_LOGFILE" ] || return 0
 	
+	local DATE
 	DATE=$(date +"%H:%M:%S  %Y-%m-%d")
+	
 	echo "########## $DATE ##########"
 	echo "IFACE=$WPA_IFACE ACTION=$WPA_ACTION"
 }
 
 # log wpa_cli environment variables
 wpa_log_environment () {
+	[ -w "$WPA_CLI_LOGFILE" ] || return 0
+
 	echo "WPA_ID=$WPA_ID WPA_ID_STR=$WPA_ID_STR"
 	echo "WPA_CTRL_DIR=$WPA_CTRL_DIR"
 }
@@ -1013,22 +1010,25 @@ ifup () {
 
 	if [ -n "$WPA_LOGICAL_IFACE" ]; then
 		if egrep -q "^iface[[:space:]]+${WPA_LOGICAL_IFACE}[[:space:]]+inet" "$INTERFACES_FILE"; then
-			
-			echo "ifup $WPA_IFACE=$WPA_LOGICAL_IFACE"
-
-			ifupdown_lock
-			
-			if grep -q "^$WPA_IFACE=$WPA_IFACE" "$IFSTATE_FILE"; then
-				# Force settings over the unconfigured "master" IFACE
-				/sbin/ifup -v --force "$WPA_IFACE=$WPA_LOGICAL_IFACE"
-			else
-				/sbin/ifup -v "$WPA_IFACE=$WPA_LOGICAL_IFACE"
-			fi
-
-			ifupdown_unlock
+			: # logical network is defined
 		else
 			echo "No network defined for \"$WPA_LOGICAL_IFACE\" in \"$INTERFACES_FILE\""
+			echo "Trying to configure the \"default\" network instead ..."
+			WPA_LOGICAL_IFACE="default"
 		fi
+			
+		echo "ifup $WPA_IFACE=$WPA_LOGICAL_IFACE"
+
+		ifupdown_lock
+		
+		if grep -q "^$WPA_IFACE=$WPA_IFACE" "$IFSTATE_FILE"; then
+			# Force settings over the unconfigured "master" IFACE
+			/sbin/ifup -v --force "$WPA_IFACE=$WPA_LOGICAL_IFACE"
+		else
+			/sbin/ifup -v "$WPA_IFACE=$WPA_LOGICAL_IFACE"
+		fi
+
+		ifupdown_unlock
 	else
 		echo "No suitable logical interface mapping for ifupdown to configure"
 	fi
@@ -1059,10 +1059,10 @@ ifdown () {
 # NB: use iproute if present, flushing the IFACE first
 #
 if_post_down_up () {
-	if [ -x /sbin/ip ]; then
-		/sbin/ip addr flush dev "$WPA_IFACE" 2>/dev/null
-		/sbin/ip link set "$WPA_IFACE" up
+	if type ip >/dev/null; then
+		ip addr flush dev "$WPA_IFACE" 2>/dev/null
+		ip link set "$WPA_IFACE" up
 	else
-		/sbin/ifconfig "$WPA_IFACE" up
+		ifconfig "$WPA_IFACE" up
 	fi
 }
